changeset 1710:27c3b6b64914

Fixed problem with descriptor
author boisy
date Sat, 14 Aug 2004 20:29:26 +0000
parents 1e026af2217c
children 12dccb1557b1
files level1/modules/term_sc6551.asm
diffstat 1 files changed, 11 insertions(+), 13 deletions(-) [+]
line wrap: on
line diff
--- a/level1/modules/term_sc6551.asm	Sat Aug 14 02:40:48 2004 +0000
+++ b/level1/modules/term_sc6551.asm	Sat Aug 14 20:29:26 2004 +0000
@@ -1,22 +1,19 @@
 ********************************************************************
 * TERM - CoCo serial device descriptor for terminal
 *
 * $Id$
 *
 * Edt/Rev  YYYY/MM/DD  Modified by
 * Comment
 * ------------------------------------------------------------------
-*          ????/??/??
-* From Tandy OS-9 Level One VR 02.00.00
 
-         nam   T1
-         ttl   CoCo serial device descriptor for terminal
+         nam   TERM
+         ttl   6551 device descriptor
 
-* Disassembled 98/08/23 21:16:45 by Disasm v1.6 (C) 1988 by RML
+* Disassembled 98/08/23 21:16:50 by Disasm v1.6 (C) 1988 by RML
 
          ifp1  
          use   defsfile
-         use   scfdefs
          endc  
 
 tylg     set   Devic+Objct
@@ -27,7 +24,7 @@
 
          fcb   UPDAT.     mode byte
          fcb   HW.Page    extended controller address
-         fdb   $0000      physical controller address
+         fdb   $FF68      physical controller address
          fcb   initsize-*-1 initilization table size
          fcb   DT.SCF     device type:0=scf,1=rbf,2=pipe,3=scf
          fcb   $00        case:0=up&lower,1=upper only
@@ -49,16 +46,17 @@
          fcb   C$QUIT     quit character
          fcb   C$BSP      backspace echo character
          fcb   C$BELL     line overflow character (bell)
-         fcb   PARNONE    init value for dev ctl reg
-         fcb   B300+WORD8+STOP1       baud rate
+         fcb   PARNONE    parity
+         fcb   STOP1+WORD8+B9600 stop bits/word size/baud rate
          fdb   name       copy of descriptor name address
-         fcb   $00        acia xon char
-         fcb   $00        acia xoff char
+         fcb   C$XON      acia xon char
+         fcb   C$XOFF     acia xoff char
          fcb   80         (szx) number of columns for display
          fcb   24         (szy) number of rows for display
+         fcb   $00        Extended type
 initsize equ   *
 
-name     fcs   /term/
+name     fcs   /TERM/
 mgrnam   fcs   /SCF/
 drvnam   fcs   /sc6551/
@@ -1,22 +1,19 @@
 ********************************************************************
-* TERM - CoCo serial device descriptor for terminal
+* TERM - 6551 device descriptor
 *
 * $Id$